@@ -54,12 +54,14 @@ class UCSResync(object):
 	def _get_listener_dir(self):
 		return self.configRegistry.get('connector/s4/listener/dir', '/var/lib/univention-connector/s4')
 
-	def _generate_filename(self):
+	def _generate_filename(self, first):
 		directory = self._get_listener_dir()
-		return os.path.join(directory, "%f" % time.time())
+		if not first:
+			return os.path.join(directory, "%f" % time.time())
+		return os.path.join(directory, "-%f" % time.time())
 
-	def _dump_object_to_file(self, object_data):
-		filename = self._generate_filename()
+	def _dump_object_to_file(self, object_data, first):
+		filename = self._generate_filename(first)
 		with open(filename, 'wb+') as fd:
 			os.chmod(filename, 0o600)
 			p = pickle.Pickler(fd)
@@ -69,11 +71,11 @@ class UCSResync(object):
 	def _search_ldap_object_orig(self, ucs_dn):
 		return self.lo.get(ucs_dn, attr=['*', '+'], required=True)
 
-	def resync(self, ucs_dns=None, ldapfilter=None):
+	def resync(self, first, ucs_dns=None, ldapfilter=None):
 		treated_dns = []
 		for dn, new in self.search_ldap(ucs_dns, ldapfilter):
 			object_data = (dn, new, {}, None)
-			self._dump_object_to_file(object_data)
+			self._dump_object_to_file(object_data, first)
 			treated_dns.append(dn)
 
 		return treated_dns
@@ -105,6 +107,7 @@ if __name__ == '__main__':
 	parser = ArgumentParser()
 	parser.add_argument("--filter", dest="ldapfilter", help="LDAP Filter")
 	parser.add_argument("dn", nargs='?', default=None)
+	parser.add_argument("--first", dest="first", action='store_true')
 	options = parser.parse_args()
 
 	if not options.dn and not options.ldapfilter:
@@ -116,7 +119,7 @@ if __name__ == '__main__':
 	treated_dns = []
 	try:
 		resync = UCSResync()
-		treated_dns = resync.resync(ucs_dns, options.ldapfilter)
+		treated_dns = resync.resync(options.first, ucs_dns, options.ldapfilter)
 	except ldap.NO_SUCH_OBJECT as ex:
 		print('ERROR: The LDAP object not found : %s' % ex.args[1])
 		if len(ex.args) == 3:
